@@ -59,7 +59,7 @@ class Images(Data):
             return self.values[0]
 
         if self.mode == 'spark':
-            return self.values.first()
+            return self.values.first().toarray()
 
     def toblocks(self, chunk_size='auto', padding=None):
         """
@@ -109,7 +109,7 @@ class Images(Data):
         from thunder.series.series import Series
 
         if chunk_size is 'auto':
-            chunk_size = str(int(1000000.0/self.shape[0]))
+            chunk_size = str(int(100000.0/self.shape[0]))
 
         n = len(self.shape) - 1
         index = arange(self.shape[0])
